@@ -95,7 +95,7 @@ used in the Czech (and other) languages.
 use strict;
 use vars qw( $VERSION $DEBUG $LEFTMIN $RIGHTMIN $errstr );
 
-$VERSION = '0.130';
+$VERSION = '1.01';
 sub Version ()	{ $VERSION; }
 
 $DEBUG ||= 0;
@@ -104,6 +104,8 @@ $DEBUG ||= 0;
 $LEFTMIN = 2;
 $RIGHTMIN = 2;
 
+my (@DATA, $DATA_LOADED);
+
 # #############################################################
 # Constructor. Parameter specifies file with patterns.
 # File is searched for \patterns{ ... } and \hyphenation{ ... }
@@ -112,7 +114,7 @@ $RIGHTMIN = 2;
 sub new {
 	my $class = shift;
 	my ($file, %opts);
-	if (scalar(keys %opts) % 2 == 1) {
+	if (scalar(@_) % 2) {
 		$file = shift;
 		%opts = @_;
 	} else {
@@ -120,7 +122,10 @@ sub new {
 		$file = $opts{'file'};
 	}
 	if (not defined $file) {
-		*FILE = \*DATA;
+		if (not defined $DATA_LOADED) {
+			@DATA = <DATA>;
+			$DATA_LOADED = 1;
+		}
 	} else {
 		open FILE, $file or do {
 			$errstr = "Error opening file `$file': $!";
@@ -158,7 +163,10 @@ sub new {
 	$leftmin = $opts{leftmin} if exists $opts{leftmin};
 	$rightmin = $opts{rightmin} if exists $opts{rightmin};
 
-	while (<FILE>) {
+	my $i = 0;
+	while ((defined $file and defined($_ = <FILE>))
+		or (not defined $file and defined($_ = $DATA[$i]))) {
+		$i++;
 		s/\%.*$//;			# comment out
 		next if 1 .. /\\patterns{/;	# find the \patterns section
 		
@@ -168,15 +176,17 @@ sub new {
 			$process_patterns->($_, $bothhyphen, $beginhyphen,
 			$endhyphen, $hyphen);
 	}
-	my $tell = $. + 1;
-	while (<FILE>) {
-		next if (( $. == $tell) .. /\\hyphenation{/);
+	my $tell = $i + 1;
+	while ((defined $file and defined($_ = <FILE>))
+		or (not defined $file and defined($_ = $DATA[$i]))) {
+		$i++;
+		next if (( $i == $tell) .. /\\hyphenation{/);
 
 		chomp;
 
 		last unless $process_hyphenation->($_, $exception);
 	}
-	close FILE;
+	close FILE if not defined $file;
 	$self->{hyphen} = $hyphen;
 	$self->{begin} = $beginhyphen;
 	$self->{end} = $endhyphen;
@@ -312,63 +322,27 @@ sub visualize {
 	$word;
 }
 
-=head1 CHANGES
-
-=over
-
-=item 0.110 Tue Dec 11 14:26:15 MET 2001
-
-Support for more languages made modular, code for German parsing
-provided by Slaven Rezic.
-
-=item 0.101 Wed Nov  3 16:06:02 MET 1999
-
-Parsing of patterns extended to allow other styles as well -- Spanish
-pattern file provided by Adrian Perez Jorge.
-
-=item 0.10 Fri Dec 11 10:58:01 MET 1998
-
-Bug fixes concering LEFTMIN and RIGHTMIN values and use of exceptions
-(thanks go to Vladimir Volovich).
-
-=item 0.06 Mon Jul 21 18:53:26 MET DST 1997
-
-Exception table handling added -- error spotted by Jon Orwant.
-
-=item 0.05 Wed Jul  9 14:49:42 MET DST 1997
-
-Added the default F<hyphen.tex> into the module and possibility to
-call the constructior without argument to get this default pattern
-file.
-
-=item 0.04 Wed Apr  9 15:41:32 MET DST 1997
-
-Hash lookup made faster.
-
-Method TeX::Hyphen::visualize() only takes one argument, it calls
-hyphenate().
-
-=item 0.03 Sun Feb 16 13:55:26 MET 1997
-
-Hash lookup made faster.
-
-Original name B<Hyphen> chaged to B<TeX::Hyphen>.
-
-=back
-
 =head1 VERSION
 
-0.130
+1.01
+
+=head1 AVAILABLE FROM
+
+http://www.adelton.com/perl/TeX-Hyphen/
+
+=head1 AUTHOR
+
+(c) 1997--2011 Jan Pazdziora.
+
+All rights reserved. This package is free software; you can
+redistribute it and/or modify it under the same terms as Perl itself.
+
+Contact the author at jpx dash perl at adelton dot com.
 
 =head1 SEE ALSO
 
 perl(1), TeX::Hyphen::czech.
 
-=head1 AUTHOR
-
-(c) 1997--2001 Jan Pazdziora, adelton@fi.muni.cz
-at Faculty of Informatics, Masaryk University, Brno
-
 =cut
 
 1;
